Items

Struct Items 

pub struct Items<'a, 'b> { /* private fields */ }
Item import builder.

Implementations

Source

impl<'a, 'b> Items<'a, 'b>

pub fn item(self, item: impl Into<String>) -> Self

Imports the given item, as by:

import module:
  - item
pub fn items(self, items: impl IntoIterator<Item = impl Into<String>>) -> Self

Imports the given items, as by:

import module:
  - item
  - ...
pub fn item_with_name( self, item: impl Into<String>, name: impl Into<String>, ) -> Self

Imports the given item under a different name, as by:

import module:
  item: name
pub fn commit(self) -> Prelude<'a, 'b>

Finish item imports.

Calling this method may be necessary to ensure changes take effect.